Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(519)

Unified Diff: remoting/host/signaling_connector.h

Issue 9147026: API for connection type (Ethernet/WIFI/WWAN ...) in NetworkChangeNotifier. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Fixed a typo Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/url_request/url_request_throttler_unittest.cc ('k') | remoting/host/signaling_connector.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/signaling_connector.h
diff --git a/remoting/host/signaling_connector.h b/remoting/host/signaling_connector.h
index 4b432f37360e9a45dfd31b87f058ca0b226a4df3..582b4ae3e864ebab31aac01740d0562b0293f776 100644
--- a/remoting/host/signaling_connector.h
+++ b/remoting/host/signaling_connector.h
@@ -24,12 +24,12 @@ namespace remoting {
// not connected it keeps trying to reconnect it until it is
// connected. It limits connection attempt rate using exponential
// backoff. It also monitors network state and reconnects signalling
// whenever online state changes or IP address changes.
class SignalingConnector
: public base::SupportsWeakPtr<SignalingConnector>,
public base::NonThreadSafe,
public SignalStrategy::Listener,
- public net::NetworkChangeNotifier::OnlineStateObserver,
+ public net::NetworkChangeNotifier::ConnectionTypeObserver,
public net::NetworkChangeNotifier::IPAddressObserver,
public GaiaOAuthClient::Delegate {
public:
@@ -67,8 +67,9 @@ class SignalingConnector
// NetworkChangeNotifier::IPAddressObserver interface.
virtual void OnIPAddressChanged() OVERRIDE;
- // NetworkChangeNotifier::OnlineStateObserver interface.
- virtual void OnOnlineStateChanged(bool online) OVERRIDE;
+ // NetworkChangeNotifier::ConnectionTypeObserver interface.
+ virtual void OnConnectionTypeChanged(
+ net::NetworkChangeNotifier::ConnectionType type) OVERRIDE;
// GaiaOAuthClient::Delegate interface.
virtual void OnRefreshTokenResponse(const std::string& user_email,
« no previous file with comments | « net/url_request/url_request_throttler_unittest.cc ('k') | remoting/host/signaling_connector.cc » ('j') | no next file with comments »
@@ -24,12 +24,12 @@ namespace remoting {
// connected. It limits connection attempt rate using exponential
// backoff. It also monitors network state and reconnects signalling
-// whenever online state changes or IP address changes.
+// whenever connection type changes or IP address changes.
class SignalingConnector
: public base::SupportsWeakPtr<SignalingConnector>,

Powered by Google App Engine
This is Rietveld 408576698